# MathJax resources endpoints for Jupyter Server

![Testing](https://github.com/jupyter-server/jupyter_server_mathjax/workflows/Testing/badge.svg)



## Basic Usage

Install from PyPI:

```sh
> pip install jupyter_server_mathjax
```

This will automatically enable the extension in Jupyter Server.

To test the installation, you can run Jupyter Server and visit the `/static/jupyter_server_mathjax/MathJax.js` endpoint:

```sh
> jupyter server
```
